package ACL2::Orden::Thm;
use base ACL2::Orden;

#
#    Orden THM: teorema sin nombre (sólo fuerza una demostración).
#    Copyright (C) 2006-2008 Antonio García Domínguez
#
#    This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

use strict;
use warnings;

use ACL2::Resultado;
use ACL2::Tags;

sub protegido_inicializar_sexpr
{
    my ($this) = @_;

    $this->{formula} = [map { uc; } @{$this->get_elems_formula}];
    $this->{params}  = {splice @{$this->{formula}}, 2};
    $this->{params}->{":OTF-FLAG"}     ||= "NIL";
}

sub protegido_inicializar_salida
{
    my ($this) = @_;

    # Errores - no hay demostración
    if (@{$this->get_errores} > 0) {
	return;
    }

    # Realizamos la demostración
    $this->{demostracion} = new ACL2::Resultado($this->{formula}->[1], 
						   ${$this->get_salida});
    $this->{exito} = $this->{demostracion}->demostrar;
}

sub protegido_cabecera
{
    my ($orden, $writer) = @_;

    # Titulo y resultado
    $writer->startTag(ACL2::Tags::THM_TAG,
		      "otf" => $orden->{params}{":OTF-FLAG"},
		      "formula" => ${$orden->get_lisp});
}

sub protegido_cuerpo
{
    my ($orden, $writer) = @_;

    # Errores - no hay demostración
    if (@{$orden->get_errores} > 0) {
	return;
    }

    $orden->{demostracion}->escribir_xml($writer);
}

1;
